@@ -11,26 +11,19 @@ import { SavedQuery } from 'app/features/explore/QueryLibrary/types';
 
 import { QueryLibraryInteractions, dirtyFieldsToAnalyticsObject } from '../QueryLibraryAnalyticsEvents';
 import { convertAddQueryTemplateCommandToDataQuerySpec } from '../utils/mappers';
+import { hasUnresolvedVariables } from '../utils/templateVariables';
 
 import { QueryLibraryActions } from './QueryLibraryActions';
 import { QueryDetails, QueryLibraryDetails } from './QueryLibraryDetails';
 
 export interface QueryLibraryFormProps {
   selectedQueryRow: SavedQuery;
-  isEditingQuery: boolean;
-  setIsEditingQuery: (isEditingQuery: boolean) => void;
   onEditQuerySuccess: (uid: string, isNew?: boolean) => void;
   usingHistory?: boolean;
 }
 
-export function QueryLibraryForm({
-  selectedQueryRow,
-  isEditingQuery,
-  setIsEditingQuery,
-  onEditQuerySuccess,
-  usingHistory,
-}: QueryLibraryFormProps) {
-  const { onSave, closeDrawer, triggerAnalyticsEvent } = useQueryLibraryContext();
+export function QueryLibraryForm({ selectedQueryRow, onEditQuerySuccess, usingHistory }: QueryLibraryFormProps) {
+  const { onSave, triggerAnalyticsEvent } = useQueryLibraryContext();
   const styles = useStyles2(getStyles);
 
   const {
@@ -70,6 +63,7 @@ export function QueryLibraryForm({
 
       triggerAnalyticsEvent(QueryLibraryInteractions.saveQuerySuccess, {
         datasourceType: datasourceType,
+        hasTemplateVariables: hasUnresolvedVariables(selectedQueryRow.query),
       });
 
       getAppEvents().publish({
@@ -86,20 +80,11 @@ export function QueryLibraryForm({
   return (
     <Box element="form" onSubmit={handleSubmit(onSubmit)} display="flex" direction="column" flex={1}>
       <Box flex={1}>
-        <QueryLibraryDetails
-          query={selectedQueryRow}
-          editingQuery={isEditingQuery}
-          setEditingQuery={setIsEditingQuery}
-          onCloseDrawer={closeDrawer}
-          onEditQuerySuccess={onEditQuerySuccess}
-          usingHistory={usingHistory}
-        />
+        <QueryLibraryDetails query={selectedQueryRow} usingHistory={usingHistory} />
       </Box>
       <div className={styles.actions}>
         <QueryLibraryActions
           selectedQueryRow={selectedQueryRow}
-          isEditingQuery={isEditingQuery}
-          setIsEditingQuery={setIsEditingQuery}
           isSavingLoading={isUpdateLoading || isAddLoading}
           usingHistory={usingHistory}
           onEditQuerySuccess={onEditQuerySuccess}
