@@ -1,45 +1,58 @@
 import { PropsWithChildren, useCallback, useEffect, useMemo, useState } from 'react';
+import { useFormContext } from 'react-hook-form';
 
 import { CoreApp } from '@grafana/data';
 import { config } from '@grafana/runtime';
 import { DataQuery } from '@grafana/schema';
 import { QueryLibraryContext, QueryLibraryDrawerOptions } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
 
-import { QueryTemplate, type OnSelectQueryType } from '../../features/explore/QueryLibrary/types';
+import { SavedQuery, type OnSelectQueryType } from '../../features/explore/QueryLibrary/types';
 
+import { QueryDetails } from './QueryLibrary/QueryLibraryDetails';
 import { QueryLibraryInteractions } from './QueryLibraryAnalyticsEvents';
 import { QueryLibraryDrawer } from './QueryLibraryDrawer';
 import { QueryLibraryEditingHeader } from './QueryLibraryEditingHeader';
-import { SaveQueryButton } from './SaveQueryButton';
-import { QueryLibraryEventsPropertyMap } from './types';
+import { SavedQueryButtons } from './SavedQueryButtons';
+import { QueryLibraryEventsPropertyMap, QueryLibraryTab } from './types';
+import { getUserStorageFavorites, setUserStorageFavorites } from './utils/favorites';
+import { hasWritePermissions } from './utils/identity';
 
 import { getQueryLibraryDrawerAction, getQueryLibraryRenderContext } from './index';
 
 export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
+  // SAVED QUERIES STATE
+  // Context / Drawer State
   const [isDrawerOpen, setIsDrawerOpen] = useState<boolean>(false);
+  const [context, setContext] = useState('unknown');
+  const [activeTab, setActiveTab] = useState(QueryLibraryTab.ALL);
   const [activeDatasources, setActiveDatasources] = useState<string[]>([]);
 
-  const [newQuery, setNewQuery] = useState<QueryTemplate | undefined>(undefined);
-  // need to curry the no-op due to the special setState((prevState) => {}) pattern
+  // Callback State
   const [onSelectQuery, setOnSelectQuery] = useState<OnSelectQueryType>(() => () => {});
-  const [context, setContext] = useState('unknown');
   const [onSave, setOnSave] = useState<(() => void) | undefined>(undefined);
+  const [userFavorites, setUserFavorites] = useState<{ [key: string]: boolean }>({});
+  // Guard function that checks if drawer is allowed to close (returns true to allow, false to prevent)
+  const [closeGuard, setCloseGuard] = useState<() => boolean>(() => () => true);
 
-  // Enhanced drawer options
+  // Query Specific State
+  const [newQuery, setNewQuery] = useState<SavedQuery | undefined>(undefined);
   const [highlightedQuery, setHighlightedQuery] = useState<string | undefined>(undefined);
+  const [isEditingQuery, setIsEditingQuery] = useState(!!newQuery);
+
+  const QueryDetailsFormMethods = useFormContext<QueryDetails>();
 
-  // Auto-clear highlight after 3 seconds
   useEffect(() => {
-    if (highlightedQuery) {
-      const timer = setTimeout(() => {
-        setHighlightedQuery(undefined);
-      }, 2000);
+    getUserStorageFavorites().then((value) => setUserFavorites(value));
+  }, []);
 
-      return () => clearTimeout(timer);
+  useEffect(() => {
+    // Update tab to All if editing a new query
+    if (newQuery && activeTab !== QueryLibraryTab.ALL) {
+      setActiveTab(QueryLibraryTab.ALL);
     }
-    return undefined;
-  }, [highlightedQuery]);
+  }, [newQuery, activeTab, setActiveTab]);
 
+  // SAVED QUERIES CALLBACKS
   const triggerAnalyticsEvent = useCallback(
     (
       handleAnalyticEvent: (properties?: QueryLibraryEventsPropertyMap) => void,
@@ -53,11 +66,61 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
     [context]
   );
 
+  const onFavorite = useCallback(
+    async (uid: string) => {
+      const prevFavorites = { ...userFavorites };
+
+      const newUserFavorites = { ...prevFavorites, [uid]: true };
+      try {
+        setUserFavorites(newUserFavorites);
+        await setUserStorageFavorites(newUserFavorites);
+        triggerAnalyticsEvent(QueryLibraryInteractions.favoriteQueryClicked, { favoriteState: true });
+      } catch (e) {
+        setUserFavorites(prevFavorites);
+      }
+    },
+    [userFavorites, triggerAnalyticsEvent]
+  );
+
+  const onUnfavorite = useCallback(
+    async (uid: string) => {
+      const prevFavorites = { ...userFavorites };
+
+      const newUserFavorites = { ...prevFavorites };
+      delete newUserFavorites[uid];
+      try {
+        setUserFavorites(newUserFavorites);
+        await setUserStorageFavorites(newUserFavorites);
+        triggerAnalyticsEvent(QueryLibraryInteractions.favoriteQueryClicked, { favoriteState: false });
+      } catch (e) {
+        setUserFavorites(prevFavorites);
+      }
+    },
+    [userFavorites, triggerAnalyticsEvent]
+  );
+
+  // Auto-clear highlight after 3 seconds
+  useEffect(() => {
+    if (highlightedQuery) {
+      const timer = setTimeout(() => {
+        setHighlightedQuery(undefined);
+      }, 2000);
+
+      return () => clearTimeout(timer);
+    }
+    return undefined;
+  }, [highlightedQuery]);
+
   const openDrawer = useCallback(
     ({ datasourceFilters, onSelectQuery, options, query }: QueryLibraryDrawerOptions) => {
+      // this means the user is trying to save a query but doesn't have write permission
+      if (!!query && !hasWritePermissions()) {
+        return;
+      }
+
       setActiveDatasources(datasourceFilters || []);
       setOnSave(() => options?.onSave);
-      // need to curry our function due to the special setState((prevState) => {}) pattern
+      // Update the callback state
       if (onSelectQuery) {
         setOnSelectQuery(() => onSelectQuery);
       }
@@ -90,18 +153,31 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
     [triggerAnalyticsEvent]
   );
 
+  const handleSetCloseGuard = useCallback((shouldAllowClose: () => boolean) => {
+    setCloseGuard(() => shouldAllowClose);
+  }, []);
+
   const closeDrawer = useCallback(
     (isSelectingQuery?: boolean, isEditingQuery?: boolean) => {
+      // Check if the close guard allows closing
+      if (!closeGuard()) {
+        return; // Guard prevented close
+      }
+
       setActiveDatasources([]);
-      // need to curry the no-op due to the special setState((prevState) => {}) pattern
+      // Reset the callback to no-op function
       setOnSelectQuery(() => () => {});
       setNewQuery(undefined);
+      setIsEditingQuery(false);
       setIsDrawerOpen(false);
+      setCloseGuard(() => () => true);
 
       // Clear enhanced options
       setHighlightedQuery(undefined);
 
       if (isEditingQuery) {
+        QueryDetailsFormMethods?.reset();
+
         triggerAnalyticsEvent(QueryLibraryInteractions.queryLibraryClosedToEditQueryInExplore);
       } else if (!isSelectingQuery && !newQuery) {
         triggerAnalyticsEvent(QueryLibraryInteractions.queryLibraryClosedWithoutSelection);
@@ -109,21 +185,36 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
         triggerAnalyticsEvent(QueryLibraryInteractions.queryLibraryClosedWithoutSavingNewQUery);
       }
     },
-    [newQuery, triggerAnalyticsEvent]
+    [newQuery, QueryDetailsFormMethods, closeGuard, triggerAnalyticsEvent]
+  );
+
+  const onAddHistoryQueryToLibrary = useCallback(
+    (newQuery: SavedQuery) => {
+      setNewQuery(newQuery);
+      setIsEditingQuery(true);
+      triggerAnalyticsEvent(QueryLibraryInteractions.saveRecentQueryClicked);
+    },
+    [triggerAnalyticsEvent]
+  );
+
+  const onTabChange = useCallback(
+    (tab: QueryLibraryTab) => {
+      triggerAnalyticsEvent(QueryLibraryInteractions.tabClicked, { tab });
+      setActiveTab(tab);
+    },
+    [triggerAnalyticsEvent, setActiveTab]
   );
 
   const contextVal = useMemo(
     () => ({
-      isDrawerOpen,
-      openDrawer,
       closeDrawer,
-      triggerAnalyticsEvent,
-      renderSaveQueryButton: (
-        query: DataQuery,
-        app?: CoreApp,
-        onUpdateSuccess?: () => void,
-        onSelectQuery?: (query: DataQuery) => void
-      ) => <SaveQueryButton query={query} app={app} onUpdateSuccess={onUpdateSuccess} onSelectQuery={onSelectQuery} />,
+      onAddHistoryQueryToLibrary,
+      onFavorite,
+      onSave,
+      onSelectQuery,
+      onTabChange,
+      onUnfavorite,
+      openDrawer,
       renderQueryLibraryEditingHeader: (
         query: DataQuery,
         app?: CoreApp,
@@ -141,29 +232,69 @@ export function QueryLibraryContextProvider({ children }: PropsWithChildren) {
           onSelectQuery={onSelectQuery}
         />
       ),
-      queryLibraryEnabled: Boolean(config.featureToggles.queryLibrary),
-      context,
+      renderSavedQueryButtons: (
+        query: DataQuery,
+        app?: CoreApp,
+        onUpdateSuccess?: () => void,
+        onSelectQuery?: (query: DataQuery) => void,
+        datasourceFilters?: string[],
+        parentRef?: React.RefObject<HTMLElement | null>,
+        showAsButtonHeader?: boolean
+      ) => (
+        <SavedQueryButtons
+          query={query}
+          app={app}
+          onUpdateSuccess={onUpdateSuccess}
+          onSelectQuery={onSelectQuery}
+          datasourceFilters={datasourceFilters || []}
+          parentRef={parentRef}
+          showAsButtonHeader={showAsButtonHeader}
+        />
+      ),
+      setActiveTab,
+      setIsEditingQuery,
       setNewQuery,
-      onSave,
+      triggerAnalyticsEvent,
+      activeDatasources,
+      activeTab,
+      context,
+      highlightedQuery,
+      isDrawerOpen,
+      isEditingQuery,
+      newQuery,
+      queryLibraryEnabled: Boolean(config.featureToggles.queryLibrary),
+      userFavorites,
+      setCloseGuard: handleSetCloseGuard,
     }),
-    [isDrawerOpen, openDrawer, closeDrawer, context, setNewQuery, onSave, triggerAnalyticsEvent]
+    [
+      closeDrawer,
+      onAddHistoryQueryToLibrary,
+      onFavorite,
+      onSave,
+      onSelectQuery,
+      onTabChange,
+      onUnfavorite,
+      openDrawer,
+      setActiveTab,
+      setIsEditingQuery,
+      setNewQuery,
+      triggerAnalyticsEvent,
+      activeDatasources,
+      activeTab,
+      context,
+      highlightedQuery,
+      isDrawerOpen,
+      isEditingQuery,
+      newQuery,
+      userFavorites,
+      handleSetCloseGuard,
+    ]
   );
 
   return (
     <QueryLibraryContext.Provider value={contextVal}>
       {children}
-      <QueryLibraryDrawer
-        isOpen={isDrawerOpen}
-        close={() => closeDrawer(false)}
-        activeDatasources={activeDatasources}
-        highlightedQuery={highlightedQuery}
-        onSelectQuery={(query) => {
-          onSelectQuery(query);
-          closeDrawer(true);
-          triggerAnalyticsEvent(QueryLibraryInteractions.selectQueryClicked);
-        }}
-        newQuery={newQuery}
-      />
+      <QueryLibraryDrawer />
     </QueryLibraryContext.Provider>
   );
 }
