@@ -1,15 +1,19 @@
 import { QueryStatus } from '@reduxjs/toolkit/query';
-import { screen, waitFor } from '@testing-library/react';
+import { screen } from '@testing-library/react';
 import { UserEvent } from '@testing-library/user-event';
+import type { JSX } from 'react';
 import { render } from 'test/test-utils';
 
+import { useGetRepositoryRefsQuery } from '@grafana/api-clients/rtkq/provisioning/v0alpha1';
 import {
   useCreateRepositoryJobsMutation,
   useGetFrontendSettingsQuery,
   useGetRepositoryFilesQuery,
   useGetResourceStatsQuery,
+  useListRepositoryQuery,
 } from 'app/api/clients/provisioning/v0alpha1';
 
+import { useConnectionOptions } from '../hooks/useConnectionOptions';
 import { useCreateOrUpdateRepository } from '../hooks/useCreateOrUpdateRepository';
 
 import { ProvisioningWizard } from './ProvisioningWizard';
@@ -22,50 +26,102 @@ jest.mock('react-router-dom-v5-compat', () => ({
   useNavigate: () => mockNavigate,
 }));
 
-jest.mock('@grafana/runtime', () => ({
-  ...jest.requireActual('@grafana/runtime'),
-  getAppEvents: () => ({
-    publish: jest.fn(),
-  }),
-}));
-
 jest.mock('../hooks/useCreateOrUpdateRepository');
+jest.mock('../hooks/useConnectionOptions');
+jest.mock('@grafana/api-clients/rtkq/provisioning/v0alpha1', () => ({
+  ...jest.requireActual('@grafana/api-clients/rtkq/provisioning/v0alpha1'),
+  useGetRepositoryRefsQuery: jest.fn(),
+}));
 jest.mock('app/api/clients/provisioning/v0alpha1', () => ({
   ...jest.requireActual('app/api/clients/provisioning/v0alpha1'),
   useGetFrontendSettingsQuery: jest.fn(),
   useGetRepositoryFilesQuery: jest.fn(),
+  useListRepositoryQuery: jest.fn(),
   useGetResourceStatsQuery: jest.fn(),
   useCreateRepositoryJobsMutation: jest.fn(),
 }));
 
-jest.mock('app/features/browse-dashboards/api/services', () => ({
-  PAGE_SIZE: 20,
-}));
-
 const mockUseCreateOrUpdateRepository = useCreateOrUpdateRepository as jest.MockedFunction<
   typeof useCreateOrUpdateRepository
 >;
+const mockUseGetRepositoryRefsQuery = useGetRepositoryRefsQuery as jest.MockedFunction<
+  typeof useGetRepositoryRefsQuery
+>;
 const mockUseGetFrontendSettingsQuery = useGetFrontendSettingsQuery as jest.MockedFunction<
   typeof useGetFrontendSettingsQuery
 >;
 const mockUseGetRepositoryFilesQuery = useGetRepositoryFilesQuery as jest.MockedFunction<
   typeof useGetRepositoryFilesQuery
 >;
+const mockUseListRepositoryQuery = useListRepositoryQuery as jest.MockedFunction<typeof useListRepositoryQuery>;
 const mockUseGetResourceStatsQuery = useGetResourceStatsQuery as jest.MockedFunction<typeof useGetResourceStatsQuery>;
 const mockUseCreateRepositoryJobsMutation = useCreateRepositoryJobsMutation as jest.MockedFunction<
   typeof useCreateRepositoryJobsMutation
 >;
+const mockUseConnectionOptions = useConnectionOptions as jest.MockedFunction<typeof useConnectionOptions>;
 
 function setup(jsx: JSX.Element) {
   return render(<StepStatusProvider>{jsx}</StepStatusProvider>);
 }
 
+async function pasteIntoInput(user: UserEvent, input: HTMLElement, value: string) {
+  await user.click(input);
+  await user.clear(input);
+  await user.paste(value);
+}
+
 async function typeIntoTokenField(user: UserEvent, placeholder: string, value: string) {
-  const resetButton = screen.queryByRole('button', { name: /Reset/i });
-  if (resetButton) {
-    await user.click(resetButton);
+  await pasteIntoInput(user, screen.getByPlaceholderText(placeholder), value);
+}
+
+async function navigateToConnectionStep(
+  user: UserEvent,
+  type: 'github' | 'gitlab' | 'bitbucket' | 'local' | 'git',
+  data?: {
+    token?: string;
+    tokenUser?: string;
+    url?: string;
+  }
+) {
+  if (type === 'github') {
+    // Select PAT option (GitHub App is the default)
+    await user.click(screen.getByLabelText(/Connect with Personal Access Token/i));
+  }
+
+  if (type !== 'local' && data?.token) {
+    const tokenPlaceholders = {
+      github: 'ghp_xxxxxxxxxxxxxxxxxxxx',
+      gitlab: 'glpat-xxxxxxxxxxxxxxxxxxxx',
+      bitbucket: 'ATBBxxxxxxxxxxxxxxxx',
+      git: 'token or password',
+    };
+    await typeIntoTokenField(user, tokenPlaceholders[type], data.token);
+  }
+
+  if ((type === 'bitbucket' || type === 'git') && data?.tokenUser) {
+    await pasteIntoInput(user, screen.getByPlaceholderText('username'), data.tokenUser);
+  }
+
+  if (type !== 'local' && data?.url) {
+    const urlPlaceholders = {
+      github: 'https://github.com/owner/repository',
+      gitlab: 'https://gitlab.com/owner/repository',
+      bitbucket: 'https://bitbucket.org/owner/repository',
+      git: 'https://git.example.com/owner/repository.git',
+    };
+    await pasteIntoInput(user, screen.getByPlaceholderText(urlPlaceholders[type]), data.url);
+  }
+
+  if (type !== 'local') {
+    await user.click(screen.getByRole('button', { name: /Configure repository$/i }));
+  }
+  // For local, the wizard starts on the connection step (authType is pre-completed), so no click needed
+
+  if (type === 'local') {
+    expect(await screen.findByRole('heading', { name: /Connect to external storage/i })).toBeInTheDocument();
+  } else {
+    expect(await screen.findByRole('heading', { name: /Configure repository/i })).toBeInTheDocument();
   }
-  await user.type(screen.getByPlaceholderText(placeholder), value);
 }
 
 async function fillConnectionForm(
@@ -79,30 +135,23 @@ async function fillConnectionForm(
     path?: string;
   }
 ) {
-  if (type !== 'local' && data.token) {
-    const tokenPlaceholders = {
-      github: 'ghp_xxxxxxxxxxxxxxxxxxxx',
-      gitlab: 'glpat-xxxxxxxxxxxxxxxxxxxx',
-      bitbucket: 'ATBBxxxxxxxxxxxxxxxx',
-      git: 'token or password',
-    };
-    await typeIntoTokenField(user, tokenPlaceholders[type], data.token);
-  }
-
-  if ((type === 'bitbucket' || type === 'git') && data.tokenUser) {
-    await user.type(screen.getByPlaceholderText('username'), data.tokenUser);
-  }
-
-  if (type !== 'local' && data.url) {
-    await user.type(screen.getByRole('textbox', { name: /Repository URL/i }), data.url);
-  }
+  // Complete authType step first (token/url inputs are here for all git providers)
+  await navigateToConnectionStep(user, type, {
+    token: data.token,
+    tokenUser: data.tokenUser,
+    url: data.url,
+  });
 
   if (type !== 'local' && data.branch) {
-    await user.type(screen.getByRole('textbox', { name: /Branch/i }), data.branch);
+    const branchCombobox = screen.getByRole('combobox');
+    await user.click(branchCombobox);
+    await user.clear(branchCombobox);
+    await user.paste(data.branch);
+    await user.keyboard('{Enter}');
   }
 
   if (data.path) {
-    await user.type(screen.getByRole('textbox', { name: /Path/i }), data.path);
+    await pasteIntoInput(user, screen.getByRole('textbox', { name: /Path/i }), data.path);
   }
 }
 
@@ -110,10 +159,27 @@ describe('ProvisioningWizard', () => {
   beforeEach(() => {
     jest.clearAllMocks();
 
+    // Mock useGetRepositoryRefsQuery for GitHub repositories
+    mockUseGetRepositoryRefsQuery.mockReturnValue({
+      data: { items: [{ name: 'main' }, { name: 'develop' }] },
+      isLoading: false,
+      error: null,
+      refetch: jest.fn(),
+    });
+
+    // Mock useConnectionOptions to prevent async state updates
+    mockUseConnectionOptions.mockReturnValue({
+      options: [],
+      isLoading: false,
+      connections: [],
+      error: undefined,
+      refetch: jest.fn(),
+    });
+
     mockUseGetFrontendSettingsQuery.mockReturnValue({
       data: {
         items: [],
-        legacyStorage: false,
+        allowImageRendering: true,
         availableRepositoryTypes: ['github', 'gitlab', 'bitbucket', 'git', 'local'],
       },
       isLoading: false,
@@ -128,6 +194,30 @@ describe('ProvisioningWizard', () => {
       refetch: jest.fn(),
     });
 
+    mockUseListRepositoryQuery.mockReturnValue({
+      data: {
+        items: [
+          {
+            metadata: { name: 'test-repo', generation: 1 },
+            status: {
+              observedGeneration: 1,
+              health: {
+                healthy: true,
+                checked: Date.now(),
+                message: [],
+              },
+            },
+          },
+        ],
+      },
+      isLoading: false,
+      isFetching: false,
+      isError: false,
+      isSuccess: true,
+      error: null,
+      refetch: jest.fn(),
+    });
+
     mockUseGetResourceStatsQuery.mockReturnValue({
       data: {
         instance: [],
@@ -183,14 +273,36 @@ describe('ProvisioningWizard', () => {
   });
 
   describe('Happy Path', () => {
-    it('should render connection step initially', async () => {
+    it('should render choose auth type step initially for GitHub', async () => {
       setup(<ProvisioningWizard type="github" />);
 
-      expect(screen.getByRole('heading', { name: /1\. Connect to external storage/i })).toBeInTheDocument();
-      expect(screen.getByText('Personal Access Token *')).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Repository URL/i })).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Branch/i })).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Path/i })).toBeInTheDocument();
+      expect(screen.getByRole('heading', { name: /Connect/i })).toBeInTheDocument();
+      expect(screen.getByRole('radio', { name: /Use a personal access token to authenticate/i })).toBeInTheDocument();
+      expect(
+        screen.getByRole('radio', { name: /Use a GitHub App for enhanced security and team colla/i })
+      ).toBeInTheDocument();
+      expect(screen.getByRole('button', { name: /Configure repository$/i })).toBeInTheDocument();
+    });
+
+    it('should render connection step after selecting auth type', async () => {
+      const { user } = setup(<ProvisioningWizard type="github" />);
+
+      // Select PAT option
+      await user.click(screen.getByLabelText(/Connect with Personal Access Token/i));
+
+      // Fill required fields on authType step
+      await typeIntoTokenField(user, 'ghp_xxxxxxxxxxxxxxxxxxxx', 'ghp_testtoken');
+      await pasteIntoInput(
+        user,
+        screen.getByRole('textbox', { name: /Repository URL/i }),
+        'https://github.com/test/repo'
+      );
+
+      // Proceed to next step
+      await user.click(screen.getByRole('button', { name: /Configure repository$/i }));
+
+      // Verify connection step
+      expect(await screen.findByRole('heading', { name: /Configure repository/i })).toBeInTheDocument();
     });
 
     it('should progress through first 3 steps successfully', async () => {
@@ -202,29 +314,34 @@ describe('ProvisioningWizard', () => {
         error: null,
         refetch: jest.fn(),
       });
+      // Mock files to ensure sync step is not skipped for folder sync
+      mockUseGetRepositoryFilesQuery.mockReturnValue({
+        data: {
+          items: [{ name: 'test.json', path: 'test.json' }],
+        },
+        isLoading: false,
+        error: null,
+        refetch: jest.fn(),
+      });
       const { user } = setup(<ProvisioningWizard type="github" />);
 
       await fillConnectionForm(user, 'github', {
         token: 'test-token',
         url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
       });
 
       await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
 
-      await waitFor(() => {
-        expect(screen.getByRole('heading', { name: /2\. Choose what to synchronize/i })).toBeInTheDocument();
-      });
+      expect(await screen.findByRole('heading', { name: /3\. Choose what to synchronize/i })).toBeInTheDocument();
 
       expect(mockUseCreateOrUpdateRepository).toHaveBeenCalled();
 
       await user.click(screen.getByRole('button', { name: /Synchronize with external storage/i }));
 
-      await waitFor(() => {
-        expect(screen.getByRole('heading', { name: /3\. Synchronize with external storage/i })).toBeInTheDocument();
-        expect(screen.getByRole('button', { name: /Begin synchronization/i })).toBeInTheDocument();
-      });
+      expect(
+        await screen.findByRole('heading', { name: /4\. Synchronize with external storage/i })
+      ).toBeInTheDocument();
+      expect(screen.getByRole('button', { name: /Begin synchronization/i })).toBeInTheDocument();
     });
 
     it('should skip sync step when there are no resources', async () => {
@@ -251,15 +368,11 @@ describe('ProvisioningWizard', () => {
       await fillConnectionForm(user, 'github', {
         token: 'test-token',
         url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
       });
 
       await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
 
-      await waitFor(() => {
-        expect(screen.getByRole('heading', { name: /2\. Choose what to synchronize/i })).toBeInTheDocument();
-      });
+      expect(await screen.findByRole('heading', { name: /3\. Choose what to synchronize/i })).toBeInTheDocument();
 
       // Should show "Choose additional settings" button instead of "Synchronize with external storage"
       expect(screen.getByRole('button', { name: /Choose additional settings/i })).toBeInTheDocument();
@@ -302,7 +415,10 @@ describe('ProvisioningWizard', () => {
         status: 400,
       };
 
-      mockSubmitData.mockRejectedValue(testResultsError);
+      // First submit (authType) succeeds, second (connection step) fails
+      mockSubmitData
+        .mockResolvedValueOnce({ data: { metadata: { name: 'test-repo-abc123' } } })
+        .mockRejectedValueOnce(testResultsError);
 
       const { user } = setup(<ProvisioningWizard type="github" />);
 
@@ -310,19 +426,21 @@ describe('ProvisioningWizard', () => {
         token: 'test-token',
         url: 'https://github.com/test/repo',
         branch: 'invalid-branch',
-        path: '/',
       });
 
       await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
 
-      await waitFor(() => {
-        expect(screen.getByText('Branch "invalid-branch" not found')).toBeInTheDocument();
-      });
+      const errors = await screen.findAllByText('Branch "invalid-branch" not found');
 
-      expect(screen.getByRole('heading', { name: /1\. Connect to external storage/i })).toBeInTheDocument();
+      // Inline error is the one with role="alert"
+      const inlineError = errors.find((el) => el.getAttribute('role') === 'alert');
+      expect(inlineError).toBeTruthy();
+
+      // Still on connection step (now step 2)
+      expect(screen.getByRole('heading', { name: /2\. Configure repository/i })).toBeInTheDocument();
     });
 
-    it('should show error alert for Status API errors', async () => {
+    it('should allow retry after non-field error on connection step', async () => {
       const mockSubmitData = jest.fn();
       const mockMutationState = {
         status: QueryStatus.uninitialized,
@@ -335,226 +453,167 @@ describe('ProvisioningWizard', () => {
         mockMutationState,
       ]);
 
-      const statusError = new Error('decrypt gitlab token: not found');
-      mockSubmitData.mockRejectedValue(statusError);
-
-      const { user } = setup(<ProvisioningWizard type="gitlab" />);
-
-      await fillConnectionForm(user, 'gitlab', {
-        token: 'invalid-token',
-        url: 'https://gitlab.com/test/repo',
-        branch: 'main',
-        path: '/',
-      });
-
-      await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
-
-      await waitFor(() => {
-        expect(screen.getByRole('alert')).toBeInTheDocument();
-        expect(screen.getByText('Repository connection failed')).toBeInTheDocument();
-      });
-
-      expect(screen.getByRole('heading', { name: /1\. Connect to external storage/i })).toBeInTheDocument();
-    });
-
-    it('should show error when repository creation fails', async () => {
-      const mockSubmitData = jest.fn();
-      const mockMutationState = {
-        status: QueryStatus.uninitialized,
-        isLoading: false,
-        error: null,
-      };
-      (mockUseCreateOrUpdateRepository as jest.Mock).mockReturnValue([
-        mockSubmitData,
-        mockMutationState,
-        mockMutationState,
-      ]);
-
-      mockSubmitData.mockResolvedValue({
-        error: {
-          kind: 'Status',
-          status: 'Failure',
-          message: 'Repository creation failed',
-          code: 500,
+      const urlError = {
+        data: {
+          kind: 'TestResults',
+          apiVersion: 'provisioning.grafana.app/v0alpha1',
+          success: false,
+          code: 400,
+          errors: [
+            {
+              type: 'FieldValueInvalid',
+              field: 'spec.github.url',
+              detail: 'Invalid repository URL',
+            },
+          ],
         },
-      });
-
-      const { user } = setup(<ProvisioningWizard type="github" />);
-
-      await fillConnectionForm(user, 'github', {
-        token: 'test-token',
-        url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
-      });
-
-      await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
-
-      await waitFor(() => {
-        expect(screen.getByRole('alert')).toBeInTheDocument();
-        expect(screen.getByText('Repository request failed')).toBeInTheDocument();
-      });
-    });
-  });
-
-  describe('Navigation and State', () => {
-    it('should handle cancel on first step', async () => {
-      const { user } = setup(<ProvisioningWizard type="github" />);
-
-      await user.click(screen.getByRole('button', { name: /Cancel/i }));
-
-      expect(mockNavigate).toHaveBeenCalledWith('/admin/provisioning');
-    });
-
-    it('should handle going back to previous step', async () => {
-      const { user } = setup(<ProvisioningWizard type="github" />);
-
-      await fillConnectionForm(user, 'github', {
-        token: 'test-token',
-        url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
-      });
-
-      await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
-
-      await waitFor(() => {
-        expect(screen.getByRole('heading', { name: /2\. Choose what to synchronize/i })).toBeInTheDocument();
-      });
-
-      await user.click(screen.getByRole('button', { name: /Previous/i }));
-
-      await waitFor(() => {
-        expect(screen.getByRole('heading', { name: /1\. Connect to external storage/i })).toBeInTheDocument();
-      });
-    });
-
-    it('should disable next button when submitting', async () => {
-      const mockSubmitData = jest.fn();
-      const mockMutationState = {
-        status: QueryStatus.uninitialized,
-        isLoading: false,
-        error: null,
-        data: undefined,
-        isUninitialized: true,
-        isSuccess: false,
-        isError: false,
-        reset: jest.fn(),
+        status: 400,
       };
 
-      (mockUseCreateOrUpdateRepository as jest.Mock).mockReturnValue([
-        mockSubmitData,
-        mockMutationState,
-        mockMutationState,
-      ]);
-
-      mockSubmitData.mockImplementation(() => new Promise((resolve) => setTimeout(resolve, 100)));
+      // authType succeeds → connection fails with URL error → retry succeeds
+      mockSubmitData
+        .mockResolvedValueOnce({ data: { metadata: { name: 'test-repo-abc123' } } })
+        .mockRejectedValueOnce(urlError)
+        .mockResolvedValueOnce({ data: { metadata: { name: 'test-repo-abc123' } } });
 
       const { user } = setup(<ProvisioningWizard type="github" />);
 
       await fillConnectionForm(user, 'github', {
         token: 'test-token',
         url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
       });
 
+      // First connection attempt — fails with URL error (field not on this step)
       await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
 
-      expect(screen.getByRole('button', { name: /Submitting.../i })).toBeDisabled();
+      // Error banner is shown
+      expect(await screen.findByRole('alert', { name: /Repository connection failed/i })).toBeInTheDocument();
+      expect(screen.getByRole('heading', { name: /2\. Configure repository/i })).toBeInTheDocument();
+
+      // User edits a visible field (branch)
+      const branchCombobox = screen.getByRole('combobox');
+      await user.clear(branchCombobox);
+      await user.paste('develop');
+      await user.keyboard('{Enter}');
+
+      // Retry — should not be silently blocked
+      await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
+
+      // Submit was called 3 times: 1 authType + 2 connection attempts
+      expect(mockSubmitData).toHaveBeenCalledTimes(3);
+
+      // Wizard advances to next step — proves no silent block
+      expect(await screen.findByRole('heading', { name: /3\. Choose what to synchronize/i })).toBeInTheDocument();
     });
   });
 
   describe('Form Validation', () => {
-    it('should validate required fields', async () => {
+    it('should validate required fields on connection step', async () => {
       const { user } = setup(<ProvisioningWizard type="github" />);
 
+      // Select PAT option (GitHub App is the default)
+      await user.click(screen.getByLabelText(/Connect with Personal Access Token/i));
+
+      await typeIntoTokenField(user, 'ghp_xxxxxxxxxxxxxxxxxxxx', 'test-token');
+      await pasteIntoInput(
+        user,
+        screen.getByPlaceholderText('https://github.com/owner/repository'),
+        'https://github.com/test/repo'
+      );
+
+      await user.click(screen.getByRole('button', { name: /Configure repository$/i }));
+      expect(await screen.findByRole('heading', { name: /2\. Configure repository/i })).toBeInTheDocument();
+
+      const clearButton = screen.getByTitle(/Clear value/i);
+      await user.click(clearButton);
+
       await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
 
-      expect(screen.getByRole('heading', { name: /1\. Connect to external storage/i })).toBeInTheDocument();
-    });
-
-    it('should show button text changes based on current step', async () => {
-      // Mock resources to ensure sync step is not skipped
-      mockUseGetResourceStatsQuery.mockReturnValue({
-        data: {
-          instance: [{ group: 'dashboard.grafana.app', count: 1 }],
-        },
-        isLoading: false,
-        error: null,
-        refetch: jest.fn(),
-      });
-
-      const { user } = setup(<ProvisioningWizard type="github" />);
-
-      expect(screen.getByRole('button', { name: /Choose what to synchronize/i })).toBeInTheDocument();
-
-      await fillConnectionForm(user, 'github', {
-        token: 'test-token',
-        url: 'https://github.com/test/repo',
-        branch: 'main',
-        path: '/',
-      });
-
-      await user.click(screen.getByRole('button', { name: /Choose what to synchronize/i }));
-
-      await waitFor(() => {
-        expect(screen.getByRole('button', { name: /Synchronize with external storage/i })).toBeInTheDocument();
-      });
+      // Should still be on connection step due to validation
+      expect(screen.getByRole('heading', { name: /2\. Configure repository/i })).toBeInTheDocument();
+      expect(screen.getByText(/Branch is required/i)).toBeInTheDocument();
     });
   });
 
   describe('Different Repository Types', () => {
     it('should render GitLab-specific fields', async () => {
-      setup(<ProvisioningWizard type="gitlab" />);
+      const { user } = setup(<ProvisioningWizard type="gitlab" />);
 
+      // Auth step fields
       expect(screen.getByText('Project Access Token *')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Repository URL/i })).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Branch/i })).toBeInTheDocument();
+
+      await navigateToConnectionStep(user, 'gitlab', {
+        token: 'glpat-test',
+        url: 'https://gitlab.com/test/repo',
+      });
+
+      // Connection step fields
+      expect(screen.getByRole('combobox')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Path/i })).toBeInTheDocument();
     });
 
     it('should render Bitbucket-specific fields', async () => {
-      setup(<ProvisioningWizard type="bitbucket" />);
+      const { user } = setup(<ProvisioningWizard type="bitbucket" />);
 
+      // Auth step fields
       expect(screen.getByText('App Password *')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Username/ })).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Repository URL/i })).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Branch/i })).toBeInTheDocument();
+
+      await navigateToConnectionStep(user, 'bitbucket', {
+        token: 'test-token',
+        tokenUser: 'test-user',
+        url: 'https://bitbucket.org/test/repo',
+      });
+
+      // Connection step fields
+      expect(screen.getByRole('combobox')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Path/i })).toBeInTheDocument();
     });
 
     it('should render Git-specific fields', async () => {
-      setup(<ProvisioningWizard type="git" />);
+      const { user } = setup(<ProvisioningWizard type="git" />);
 
+      // Auth step fields
       expect(screen.getByText('Access Token *')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Username/ })).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Repository URL/i })).toBeInTheDocument();
-      expect(screen.getByRole('textbox', { name: /Branch/i })).toBeInTheDocument();
+
+      await navigateToConnectionStep(user, 'git', {
+        token: 'test-token',
+        tokenUser: 'test-user',
+        url: 'https://git.example.com/test/repo.git',
+      });
+
+      // Connection step fields
+      expect(screen.getByRole('combobox')).toBeInTheDocument();
       expect(screen.getByRole('textbox', { name: /Path/i })).toBeInTheDocument();
     });
 
     it('should render local repository fields', async () => {
-      setup(<ProvisioningWizard type="local" />);
+      const { user } = setup(<ProvisioningWizard type="local" />);
+
+      await navigateToConnectionStep(user, 'local');
 
       expect(screen.getByRole('textbox', { name: /Path/i })).toBeInTheDocument();
       expect(screen.queryByPlaceholderText('ghp_xxxxxxxxxxxxxxxxxxxx')).not.toBeInTheDocument();
       expect(screen.queryByPlaceholderText('glpat-xxxxxxxxxxxxxxxxxxxx')).not.toBeInTheDocument();
       expect(screen.queryByPlaceholderText('ATBBxxxxxxxxxxxxxxxx')).not.toBeInTheDocument();
       expect(screen.queryByRole('textbox', { name: /Repository URL/i })).not.toBeInTheDocument();
-      expect(screen.queryByRole('textbox', { name: /Branch/i })).not.toBeInTheDocument();
+      expect(screen.queryByRole('combobox')).not.toBeInTheDocument();
     });
 
     it('should accept tokenUser input for Bitbucket provider', async () => {
       const { user } = setup(<ProvisioningWizard type="bitbucket" />);
 
-      await fillConnectionForm(user, 'bitbucket', {
-        token: 'test-token',
-        tokenUser: 'test-user',
-        url: 'https://bitbucket.org/test/repo',
-        branch: 'main',
-        path: '/',
-      });
+      await typeIntoTokenField(user, 'ATBBxxxxxxxxxxxxxxxx', 'test-token');
+      await pasteIntoInput(user, screen.getByPlaceholderText('username'), 'test-user');
+      await pasteIntoInput(
+        user,
+        screen.getByPlaceholderText('https://bitbucket.org/owner/repository'),
+        'https://bitbucket.org/test/repo'
+      );
 
       expect(screen.getByDisplayValue('test-user')).toBeInTheDocument();
     });
@@ -562,13 +621,13 @@ describe('ProvisioningWizard', () => {
     it('should accept tokenUser input for Git provider', async () => {
       const { user } = setup(<ProvisioningWizard type="git" />);
 
-      await fillConnectionForm(user, 'git', {
-        token: 'test-token',
-        tokenUser: 'test-user',
-        url: 'https://git.example.com/test/repo.git',
-        branch: 'main',
-        path: '/',
-      });
+      await typeIntoTokenField(user, 'token or password', 'test-token');
+      await pasteIntoInput(user, screen.getByPlaceholderText('username'), 'test-user');
+      await pasteIntoInput(
+        user,
+        screen.getByPlaceholderText('https://git.example.com/owner/repository.git'),
+        'https://git.example.com/test/repo.git'
+      );
 
       expect(screen.getByDisplayValue('test-user')).toBeInTheDocument();
     });
